<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/*
 * Evp Events Custom post type
 */

add_action('init', 'evp_event_post');

function evp_event_post() {
    register_post_type(
            'EvpEvents', array(
        'labels' => array(
            'name' => 'Evp Events',
            'singular_name' => 'Evp Event',
            'add_new' => 'Add New',
            'add_new_item' => 'Add New Evp Event',
            'edit' => 'Edit',
            'edit_item' => 'Edit Evp Event',
            'new_item' => 'New Evp Event',
            'view' => 'View',
            'view_item' => 'View Evp Event',
            'search_items' => 'Search Evp Event',
            'not_found' => 'No Evp Event found',
            'not_found_in_trash' => 'No Evp Event found in Trash',
            'parent' => 'Parent evpevent'
        ),
        'public' => true,
        'menu_position' => 15,
        'supports' => array('title', 'editor'),
        'has_archive' => true,
        'show_in_menu' => false,
            )
    );
}

/* add post meta for Evp Events form selection */
add_action('add_meta_boxes', 'evp_form_box');

function evp_form_box() {
    add_meta_box('evp_form_box', 'Select Volunteer Form By Name Or Form Id <span class="evp-required" aria-required="true"> * </span>', 'evp_form_fields', 'evpevents', 'normal', 'high');
}

function evp_form_fields($post) {
    global $wpdb;
    $form_selection = get_post_meta($post->ID, 'eventform', true);
    $tblname = $wpdb->prefix . "mwp_forms_free";
    $tableforms = $wpdb->get_results("select * from `" . $tblname . "`");
    if (!empty($tableforms)) {
        ?>
        <select name="eventform" id="eventform" required="">
            <option value=""><?php _e("Please Select", "event-volunteer"); ?></option>   
            <?php
            foreach ($tableforms as $tableform) {
                ?>
                <option value="<?php echo $tableform->id; ?>" <?php selected($form_selection, $tableform->id); ?>><?php
                    if ($tableform->title) {
                        echo $tableform->title;
                    } else {
                        ?>&nbsp;<?php
                        echo "Form ID " . $tableform->id;
                    }
                    ?></option>
            <?php } ?>
        <?php } else {
            ?>
            <select name="eventform" id="eventform">
                <option><?php _e("No Form Select.", "event-volunteer"); ?></option></select>
        <?php } ?>
    </select></br>
    <?php
}

/* add post meta for location */
add_action('add_meta_boxes', 'evp_event_box');

function evp_event_box() {
    add_meta_box('evp_meta_box', 'Select Location and Date', 'evp_event_fields', 'evpevents', 'normal', 'high');
}

add_action('save_post_evpevents', 'evp_save_eventbox');

function evp_save_eventbox() {
    global $post;
    if (isset($_POST["event_location"])) {
        //UPDATE: 
        $save_event_location = sanitize_text_field($_POST['event_location']);
        //END OF UPDATE
        update_post_meta($post->ID, 'gwl_event_fields', $save_event_location);    
    }

    if (isset($_POST['eventform'])) {
        update_post_meta($post->ID, 'eventform', sanitize_text_field($_POST['eventform']));
    }

    if (isset($_POST['start_event'])) {
        update_post_meta($post->ID, 'start_event', sanitize_text_field($_POST['start_event']));
    }

    if (isset($_POST['end_event'])) {
        update_post_meta($post->ID, 'end_event', sanitize_text_field($_POST['end_event']));
    }

    if (isset($_POST['start_time'])) {
        $start_time = date("H:i:s", strtotime(sanitize_text_field($_POST['start_time'])));
        update_post_meta($post->ID, 'start_time', $start_time);
    }

    if (isset($_POST['end_time'])) {
        $end_time = date("H:i:s", strtotime(sanitize_text_field($_POST['end_time'])));
        update_post_meta($post->ID, 'end_time', $end_time);
    }

    if (isset($_POST['all_day'])) {
        update_post_meta($post->ID, "all_day", sanitize_text_field($_POST["all_day"]));
    }

    if (!empty($post->ID)) {
        $event_start = get_post_meta($post->ID, 'start_event', true);

        $event_end = get_post_meta($post->ID, 'end_event', true);
        $endDate = strtotime($event_end);
    
    $month = sanitize_text_field($_POST['repmonth']);
    $days = array();     
    foreach ($_POST['repday'] as $pstvalue) {
        $days[] = sanitize_text_field($pstvalue);   
    }  
           
    }
    $all_combine = array();
    if (!empty($days)) {
        foreach ($days as $day) {
            for ($i = strtotime($day, strtotime($event_start)); $i <= $endDate; $i = strtotime('+1 week', $i)) {
                $all_combine[] = date('Y-m-d', $i);
            }
        }
    }
    $recurdate = $all_combine;
    if (!empty($post->ID)) {
        if ($_POST['all_day'] == "eve_series") {
            update_post_meta($post->ID, "repday", $days);
            update_post_meta($post->ID, "repmonth", $month);
            update_post_meta($post->ID, "recurring_event", $recurdate);
            update_post_meta($post->ID, "weekly", $_POST["weekly"]);
        }
    }
}

function evp_event_fields($post) {
    $event_location = get_post_meta($post->ID, 'gwl_event_fields', true);
    $start_event = get_post_meta($post->ID, 'start_event', true);
    $end_event = get_post_meta($post->ID, 'end_event', true);
    $start_time = get_post_meta($post->ID, 'start_time', true);
    $end_time = get_post_meta($post->ID, 'end_time', true);
    $event_weekly = get_post_meta($post->ID, 'weekly', true);
    $event_monthly = get_post_meta($post->ID, 'monthly', true);
    $recurr = get_post_meta($post->ID, 'recurring_event', true);
    $all_day = get_post_meta($post->ID, 'all_day', true);
    $repday = get_post_meta($post->ID, 'repday', true);
    $repmonth = get_post_meta($post->ID, 'repmonth', true);
    $chk = get_post_meta($post->ID, 'all_day', true);
    $cstm = get_post_meta($post->ID, 'custom', true);
    $cstmvalue = get_post_meta($post->ID, "custom_value", true);

    echo $cstmvalue;

    if (empty($cstm)) {
        $cstm = array();
    }
    if (empty($repday)) {
        $repday = array();
    }
    if (empty($repmonth)) {
        $repmonth = array();
    }
    global $post;
    $args = query_posts(array(
        'post_type' => 'locations',
        'showposts' => -1,
        'orderby' => 'title',
        'post_status' => 'publish',
        'order' => 'asc')
    );
    if (!empty($args)) {
        ?>   
        <label> <?php _e("Select Location", "event-volunteer"); ?><span class="evp-required" aria-required="true"> * </span></label>

        <select name="event_location" id="event_location" required="">
            <option value=""><?php _e("Please Select", "event-volunteer"); ?></option>     
            <?php
            foreach ($args as $arg) {
                if (!empty($arg->post_title)) {
                    ?>
                    <option value="<?php echo $arg->post_name; ?>" <?php selected($event_location, $arg->post_name); ?>><?php echo $arg->post_title ?></option>
                <?php }
            }
            ?>
        </select> </br></br>
    <?php } else { ?>
        <h4><?php _e("No Location Found.", "event-volunteer"); ?></h4>
    <?php } ?> 

    <?php wp_nonce_field('my_meta_box_nonce', 'meta_box_nonce'); ?>
    <label for="start_event"><?php _e("Start Event", "event-volunteer"); ?><span class="evp-required" aria-required="true"> * </span></label>
    <input type="text" name="start_event" id="start_event" value="<?php echo $start_event; ?>" required="" readonly=""/>&nbsp; <input type="text" name="start_time" id="start_time" value="<?php echo date("g:i a", strtotime($start_time)); ?>"/></br></br>

    <label for="end_event"> <?php _e("End Event", "event-volunteer"); ?><span class="evp-required" aria-required="true"> * </span></label>
    <input type="text" name="end_event" id="end_event" value="<?php echo $end_event; ?>" required="" readonly=""/>&nbsp; <input type="text" name="end_time" id="end_time" value="<?php echo date("g:i a", strtotime($end_time)); ?>"/></br></br>

    <input type="hidden" name="recurring_event" id="recurring_event" value="<?php echo maybe_serialize($recurr); ?>"/> 
    <p><b><label for="Select Date Type"><?php _e("Select Date Type", "event-volunteer"); ?><span class="evp-required" aria-required="true"> * </label></b></p>
    <?php _e("All Dates ", "event-volunteer"); ?> <input type="radio" name="all_day" id="allday" value="allday"  <?php
    if ($chk == "allday") {
        echo "checked";
    }
    ?> required="" >

    <?php _e("Event Series ", "event-volunteer"); ?> <input type="radio" name="all_day" id="myCheck" value="eve_series" <?php
    if ($chk == "eve_series") {
        echo "checked";
    }
    ?> onclick="evp_event_series_function()" required="" > 


    <p id="text" style="display:none">
    <?php _e("Weekly", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> * </span><input type = "checkbox" name="weekly"  id="weekly" onclick="wp_week()"  value="1" <?php checked($event_weekly, 1); ?>  >
    </p>
    <p id="weekbtn" style="display:none">
        <select name="repday[]" id="repday"  multiple="multiple"> 
            <option value="Monday" <?php selected(in_array("Monday", $repday)); ?>><?php _e("Monday", "event-volunteer"); ?></option>
            <option value="Tuesday" <?php selected(in_array("Tuesday", $repday)); ?>><?php _e("Tuesday", "event-volunteer"); ?></option>
            <option value="Wednesday" <?php selected(in_array("Wednesday", $repday)); ?>><?php _e("Wednesday", "event-volunteer"); ?></option>
            <option value="Thursday" <?php selected(in_array("Thursday", $repday)); ?>><?php _e("Thursday", "event-volunteer"); ?></option>
            <option value="Friday" <?php selected(in_array("Friday", $repday)); ?>><?php _e("Friday", "event-volunteer"); ?></option>
            <option value="Saturday" <?php selected(in_array("Saturday", $repday)); ?>><?php _e("Saturday", "event-volunteer"); ?></option>
            <option value="Sunday" <?php selected(in_array("Sunday", $repday)); ?>><?php _e("Sunday", "event-volunteer"); ?></option>    
        </select>   
    </p>  




    <?php
}

/* Add Event post meta for Number of Volunteer */
add_action('add_meta_boxes', 'evp_num_vol');

function evp_num_vol() {
    add_meta_box('vol_form_box', 'Number of Volunteer', 'evp_vol_form', 'evpevents', 'normal', 'high');
}

function evp_vol_form($post) {
    global $wpdb;
    $volform = get_post_meta($post->ID, 'evp_volform_num', true);
    ?>
    <input type="number" name="evp_volform" value="<?php echo $volform ?>" min="1" />

    <?php
}

add_action('save_post_evpevents', 'evp_save_vol_form');

function evp_save_vol_form() {
    global $post;
    if (isset($_POST["evp_volform"])) {
        $evp_volform = sanitize_text_field($_POST['evp_volform']);
        update_post_meta($post->ID, 'evp_volform_num', $evp_volform);
    }
}

/*
 * Add Event post meta for Set Email Reminder 
 * Number of Days Prior to Event Volunteer Send Reminder
 */


add_action('add_meta_boxes', 'evp_email_reminder_day_notification');

function evp_email_reminder_day_notification() {
    add_meta_box('evp_email_reminder_day_form_box', 'Number of Days Prior to Event Volunteer Send Reminder <span class="evp-required" aria-required="true"> * </span>', 'evp_email_reminder_day', 'evpevents', 'normal', 'high');
}

function evp_email_reminder_day($post) {
    global $wpdb;
    $evp_email_reminder_day = get_post_meta($post->ID, 'evp_email_reminder_day', true);
    ?>
    <input type="number" name="evp_email_reminder_day" value="<?php echo $evp_email_reminder_day ?>" min="1" required=""/>

    <?php
}

add_action('save_post_evpevents', 'evp_save_email_reminder_day');

function evp_save_email_reminder_day() {
    global $post;
    if (isset($_POST["evp_email_reminder_day"])) {
        $save_evp_email_reminder_day = sanitize_text_field($_POST['evp_email_reminder_day']);
        update_post_meta($post->ID, 'evp_email_reminder_day', $save_evp_email_reminder_day);
    }
}

/*
 * Event Task List dropdown meta box 
 */

function evp_event_taskbox() {
    add_meta_box('evp_meta_task_box', 'Select Event Task <span class="evp-required" aria-required="true"> * </span>', 'evp_task_name_field', 'evpevents', 'normal', 'high');
}

add_action('add_meta_boxes', 'evp_event_taskbox');

function evp_task_name_field($post) {
    $title = $post->post_title;
    $eventid = get_post_meta($post->ID, 'evp_task_name', true);
    $evp_vol_name = get_post_meta($post->ID, 'evp_selectvol_name', true);
    global $post;
    $args = query_posts(array(
        'post_type' => 'evpevents_task',
        'showposts' => -1,
        'orderby' => 'title',
        'post_status' => 'publish',
        'order' => 'asc')
    );
    if (!empty($args)) {
        ?>
        <select name="evp_task_admin[]" id="evp_task_admin" required="" multiple="multiple"> 
            <?php
            foreach ($args as $arg) {
                $evp_task_array = explode(',', $eventid);
                if (!empty($arg->post_title)) {
                    ?>
                    <option value="<?php echo $arg->ID ?>" <?php selected(in_array($arg->ID, $evp_task_array)); ?>><?php echo $arg->post_title; ?></option>
                <?php } ?>
                <?php
            }
        } else {
            ?>
            <h4><?php _e("No Task Found.", "event-volunteer"); ?></h4>  
    <?php } ?>    
    </select>
    <?php
    wp_nonce_field('my_meta_box_nonce', 'meta_box_nonce');
}

function evp_task_save_eventbox() {
    global $post;
    if (isset($_POST["evp_task_admin"])) {
        $evp_task = $_POST['evp_task_admin'];

        $post_ids = array();
        foreach ($_POST['evp_task_admin'] as $pstvalue) {
            $post_ids[] = sanitize_text_field($pstvalue);
        }

        if (!empty($evp_task)) {
            $save_evp_task_name = implode(',', $post_ids);
            update_post_meta($post->ID, 'evp_task_name', $save_evp_task_name);
        }
    }
}

add_action('save_post_evpevents', 'evp_task_save_eventbox');
