<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/*
 * Location Custom post type
 */

add_action('init', 'evp_location_post');

function evp_location_post() {

    register_post_type('Locations', array(
        'labels' => array(
            'name' => 'Evp Location',
            'singular_name' => 'location',
            'add_new' => 'Add New',
            'add_new_item' => 'Add New Evp Location',
            'edit' => 'Edit',
            'edit_item' => 'Edit Evp Location',
            'new_item' => 'New Evp Location',
            'view' => 'View',
            'view_item' => 'View Evp Location',
            'search_items' => 'Search Evp Location',
            'not_found' => 'No Evp Location found',
            'not_found_in_trash' => 'No Evp Location found in Trash',
            'parent' => 'Parent location'
        ),
        'public' => true,
        'menu_position' => 15,
        'supports' => array('title'),
        'has_archive' => true,
        'show_in_menu' => false,
    ));
}

add_action('add_meta_boxes', 'evp_location_box');

function evp_location_box() {
    add_meta_box('my-meta-box-id', 'Enter Details', 'evp_location_fields', 'locations', 'normal', 'high');
}

function evp_location_fields() {

    global $post;

    $event_add = get_post_meta($post->ID, 'event_address', true);
    $event_city = get_post_meta($post->ID, 'event_city', true);
    $event_state = get_post_meta($post->ID, 'event_state', true);
    $event_zip = get_post_meta($post->ID, 'event_zip', true);
    $event_lat = get_post_meta($post->ID, 'event_latitude', true);
    $event_long = get_post_meta($post->ID, 'event_longitude', true);

    wp_nonce_field('my_meta_box_nonce', 'meta_box_nonce');
    ?>
    <div class="event_box">
        <div class="event-section"><?php _e("Address ", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> * </span> </div>
        <div class="input_box">
            <input type="text" name="eventaddress" id="eventaddress" class="loc-data" value="<?php echo $event_add; ?>" required=""/>
        </div>
    </div>

    <div class="event_box">
        <div class="event-section"> <?php _e("City ", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> * </span> </div>
        <div class="input_box">
            <input type="text" name="eventcity" id="eventcity" class="loc-data" value="<?php echo $event_city; ?>" required=""/></br>
        </div>
    </div>

    <div class="event_box">
        <div class="event-section"> <?php _e("State ", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> * </span> </div>
        <div class="input_box">
            <input type="text" name="eventstate" id="eventstate" class="loc-data" value="<?php echo $event_state; ?>" required=""/></br>
        </div>
    </div>

    <div class="event_box"> 
        <div class="event-section"> <?php _e("Zip ", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> * </span> </div>
        <div class="input_box">
            <input type="text" name="eventzip" id="eventzip" class="loc-data" value="<?php echo $event_zip; ?>" required=""/></br>
        </div>
    </div>

    <div class="event_box"> 
        <div class="event-section"> <?php _e("Latitude (to display map)", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> * </span> </div>
        <div class="input_box">
            <input type="text" name="eventlatitude" id="eventlatitude" class="loc-data" value="<?php echo $event_lat; ?>" required=""/></br>
        </div>
    </div>

    <div class="event_box"> 
        <div class="event-section"> <?php _e("Longitude (to display map)", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> * </span> </div>
        <div class="input_box">
            <input type="text" name="eventlongitude" id="eventlongitude" class="loc-data" value="<?php echo $event_long; ?>" required=""/></br>   
        </div>
    </div>
    <?php
}

// Update/Save cat metadata
add_action('save_post_locations', 'save_location_metadata');

function save_location_metadata($post_id) {

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE)
        return;

    if (!isset($_POST['meta_box_nonce']) || !wp_verify_nonce($_POST['meta_box_nonce'], 'my_meta_box_nonce'))
        return;

    if (!current_user_can('edit_post'))
        return;

    if (isset($_POST['eventaddress']))
        update_post_meta($post_id, 'event_address', sanitize_text_field($_POST['eventaddress']));

    if (isset($_POST['eventcity']))
        update_post_meta($post_id, 'event_city', sanitize_text_field($_POST['eventcity']));

    if (isset($_POST['eventstate']))
        update_post_meta($post_id, 'event_state', sanitize_text_field($_POST['eventstate']));

    if (isset($_POST['eventzip']))
        update_post_meta($post_id, 'event_zip', sanitize_text_field($_POST['eventzip']));

    if (isset($_POST['eventlatitude']))
        update_post_meta($post_id, 'event_latitude', sanitize_text_field($_POST['eventlatitude']));

    if (isset($_POST['eventlongitude']))
        update_post_meta($post_id, 'event_longitude', sanitize_text_field($_POST['eventlongitude']));
}

add_shortcode('evp_loc', 'evp_display_loc');

function evp_display_loc() {
    global $post;
    query_posts(array(
        'post_type' => 'locations',
        'post_status' => 'publish',
        'showposts' => -1
    ));
    ?>

    <div class="col-sm-12">
    <?php
    $i = 1;
    while (have_posts()) : the_post();
        $event_add = get_post_meta($post->ID, 'event_address', true);
        $event_city = get_post_meta($post->ID, 'event_city', true);
        $event_state = get_post_meta($post->ID, 'event_state', true);
        $event_zip = get_post_meta($post->ID, 'event_zip', true);
        $event_lat = get_post_meta($post->ID, 'event_latitude', true);
        $event_long = get_post_meta($post->ID, 'event_longitude', true);
        ?>
            <div class="box col-sm-4 ">
                <p><?php _e("Event Name", "event-volunteer"); ?> :- <?php echo get_the_title() ?></p>
                <p><?php _e("Event Address", "event-volunteer"); ?> :- <?php echo $event_add; ?></p>
                <p><?php _e("Event City", "event-volunteer"); ?> :- <?php echo $event_city; ?></p>
                <p><?php _e("Event State", "event-volunteer"); ?> :- <?php echo $event_state; ?></p>
                <p><?php _e("Event Zip", "event-volunteer"); ?> :- <?php echo $event_zip; ?></p>
                <p><?php _e("Event Latitude", "event-volunteer"); ?> :- <?php echo $event_lat; ?></p>
                <p><?php _e("Event Longitude", "event-volunteer"); ?> :- <?php echo $event_long; ?></p>
                <?php the_post_thumbnail(); ?>
            
                <div id="map-<?php echo $i; ?>" style="height:250px;"></div>
            </div>
            <script type="text/javascript">initialize(<?php echo $i; ?>,<?php echo $event_lat; ?>,<?php echo $event_long; ?>);</script>
            <?php $i++;
        endwhile; ?>

    </div>

    <?php
    wp_reset_postdata();
}
