<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}
ob_start();

function evp_user_registration() {
    if (!is_user_logged_in()) {
        $registration_enabled = get_option('users_can_register');
        if ($registration_enabled) {
            $output = evp_registration_form_fields();
        } else {
            $output = __('Sorry, user registration is not enabled on this site, please enable it.');
        }
        return $output;
    }
}

/*
 *  Shortcode for Custom User Registration Form
 */

add_shortcode('evp_registration', 'evp_user_registration');

function evp_registration_form_fields() {

    $error = '';
    $success = '';
    global $wpdb, $PasswordHash, $current_user, $user_ID;
    $ustatus = 0;

    if (isset($_POST['task']) && $_POST['task'] == 'register') {

        $password1 = sanitize_text_field($_POST['password1']);
        $password2 = sanitize_text_field($_POST['password2']);
        $first_name = sanitize_text_field($_POST['first_name']);
        $last_name = sanitize_text_field($_POST['last_name']);
        $email = sanitize_text_field($_POST['email']);
        $username = sanitize_text_field($_POST['username']);
        $event_id = sanitize_text_field($_POST['event_id']);

        $formid = get_post_meta($event_id, 'eventform', true);

        if ($email == "" || $password1 == "" || $password2 == "" || $username == "" || $first_name == "" || $last_name == "") {
            $error = '<span class="evp-required">Please don\'t leave the required fields.</span>';
        }
        else if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            $error = '<span class="evp-required">Invalid email address.</span>';
        } 
        // Password must be strong
       else if(preg_match("/^.*(?=.{8,})(?=.*[0-9])(?=.*[a-z])(?=.*[A-Z]).*$/", $_POST["password1"]) === 0)
       {       
        $error = '<span class="evp-required">Password must be at least 8 characters and must contain at least one lower case letter, one upper case letter and one digit</span>';
         }
        else if ($password1 <> $password2) {
            $error = '<span class="evp-required">Password do not match.</span>'; 
        } else {
            $user_id = wp_insert_user(array('first_name' => apply_filters('pre_user_first_name', $first_name), 'last_name' => apply_filters('pre_user_last_name', $last_name), 'user_pass' => apply_filters('pre_user_user_pass', $password1), 'user_login' => apply_filters('pre_user_user_login', $username), 'user_email' => apply_filters('pre_user_user_email', $email), 'role' => 'subscriber'));
            if (is_wp_error($user_id)) {
                echo '<p> <span class="evp-required">'.$user_id->get_error_message().'</span></p>';
            } else {
                do_action('user_register', $user_id);
                update_user_meta($user_id, 'repetitive_user_status', $ustatus);
                if (!empty(evp_send_welcome_email_to_new_user($user_id, $event_id, $password1))) {
                    evp_send_welcome_email_to_new_user($user_id, $event_id, $password1);
                }
// Auto Login User after Redirect Volunteer Tab                
                wp_set_current_user($user_id);
                wp_set_auth_cookie($user_id);
                $user = get_user_by('id', $user_id);
                do_action('wp_login', $user->user_login);
                wp_redirect(get_the_permalink() . "#volunteer_tab");
                exit();
            }
        }
    }
    ?>

    <div id="message">
        <?php
        if (!empty($err)) :
            echo '<p class="error">' . $err . '';
        endif;
        ?>

        <?php
        if (!empty($success)) :
            echo '<p class="error">' . $success . '';
        endif;
        ?>
    </div>
    <p><?php
        if ($success != "") {
            echo $success;
        }
        ?> <?php
        if ($error != "") {
            echo $error;
        }
        ?></p>
    <form method="post" action="<?php the_permalink(); ?>#signup_tab"  id="e_registration">

        <p><label><?php _e("First Name", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> *</span></label></p>
        <p><input type="text" value="" name="first_name" id="first_name" /></p>

        <p><label><?php _e("Last Name", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> *</span></label></p>
        <p><input type="text" value="" name="last_name" id="last_name" /></p>

        <p><label><?php _e("Email", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> *</span></label></p>
        <p><input type="text" value="" name="email" id="email" /></p>

        <p><label><?php _e("Username", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> *</span></label></p>
        <p><input type="text" value="" name="username" id="username" /></p>

        <p><label><?php _e("Password", "event-volunteer"); ?> <span class="evp-required" aria-required="true"> *</span></label></p>
        <p><input type="password" value="" name="password1" id="password1" /></p>

        <p><label><?php _e("Confirm Password", "event-volunteer"); ?><span class="evp-required" aria-required="true"> *</span></label></p>
        <p><input type="password" value="" name="password2" id="password2" /></p>

        <button type="submit" name="btnregister" id=btnregister" class="button" ><?php _e("Submit", "event-volunteer"); ?></button>

        <input type="hidden" name="task" value="register" />
        <input type="hidden" name="wpbiker_nonce_field" value="wpbikerform" />
        <input type="hidden" name="event_id" value="<?php echo get_the_ID(); ?>">


    </form>
    <?php
}

/*
 *  Shortcode for Custom User Login Form
 */

function evp_user_login() {

    global $wpdb;
    if (isset($_POST['logintask'])) {

        $username = sanitize_text_field($_REQUEST['username']);
        $password = sanitize_text_field($_REQUEST['password']);

        $login_data = array();
        $login_data['user_login'] = $username;
        $login_data['user_password'] = $password;

        $user_verify = wp_signon($login_data, false);

        if (is_wp_error($user_verify)) {
            wp_redirect(get_the_permalink() . "?Login=Invlaid");
            exit();
        } else {
            wp_redirect(get_the_permalink() . "#volunteer_tab");
            exit();
        }
    }
    ?>
    <form id="wp_login_form" action="<?php the_permalink(); ?>#login_tab" method="post"> 
        <label class="my-username" ><?php _e("Username", "event-volunteer"); ?> </label><br> 
        <input type="text" name="username" class="text" value=""><br> 
        <label class="my-password" ><?php _e("Password", "event-volunteer"); ?> </label><br>
        <input type="password" name="password" class="text" value=""> <br> 
        <br><br> 
        <input type="hidden" name="logintask" value="login" />
        <input type="submit" id="submitbtn" name="submit" value="Login"> 
        <input type="hidden" name="wpbiker_nonce_field" value="wpbikerform" />
    </form>
    <?php
}

add_shortcode('evp_login', 'evp_user_login');
